@@ -400,7 +400,7 @@ void K3b::CdrecordWriter::start()
 
     qDebug() << "***** " << d->cdrecordBinObject->name() << " parameters:\n";
     QString s = d->process.joinedArgs();
-    qDebug() << s << flush;
+    qDebug() << s << Qt::flush;
     emit debuggingOutput( d->cdrecordBinObject->name() + " command:", s);
 
     d->currentTrack = 0;
@@ -540,7 +540,7 @@ void K3b::CdrecordWriter::slotStdLine( const QString& line )
                 size = d->tracks[d->currentTrack-1].size;
             }
             else {
-                qCritical() << "(K3b::CdrecordWriter) Did not parse all tracks sizes!" << endl;
+                qCritical() << "(K3b::CdrecordWriter) Did not parse all tracks sizes!" << Qt::endl;
             }
 
             if( !d->writingStarted ) {
